@@ -4,7 +4,6 @@ use strict;
 
 use Template;
 
-use Data::Dumper;
 use DateTime;
 use Calendar::Model;
 
@@ -20,8 +19,7 @@ my $holidays = {
     '2012-12-26' => 'Boxing Day',
 };
 
-# create Template object
 my $template = Template->new({ INCLUDE_PATH => 'templates', POST_CHOMP=> 1,});
-# process input template, substituting variables
+# process fullpage template, with events
 $template->process('calendar.tt', {cal => $cal, events => $events, holidays => $holidays })
 || die $template->error();
